@@ -1,33 +1,35 @@
 import PySimpleGUI as sg
 import ast
 import pandas as pd
-from NetLogoDOE.src.gui.custom_components import title, explanation, question_mark
+from NetLogoDOE.src.gui.custom_components import title, explanation, question_mark_button
+from NetLogoDOE.src.gui.custom_windows import show_help_window
+from NetLogoDOE.src.gui.help_dictionary import help_text
 
 
 class ImportScreen:
 
     def __init__(self):
         button_size = (25, 1)
-        button_pad = ((0, 0), (20, 0))
+        button_pad = ((5, 0), (20, 0))
         self.layout = [[title('Import results')],
                        [sg.Input(key='import_dummy_experiment_results', enable_events=True, visible=False, size=(0, 0)),
                         sg.FileBrowse('Import experiment results', file_types=[("Text Files", "*.txt")],
                                       target='import_dummy_experiment_results',
                                       key='import_experiment_results_button', size=button_size, pad=button_pad),
-                        question_mark('Help')],
+                        question_mark_button('import_experiment_results_help_button', padding=button_pad)],
                        [explanation('whatever needs ot be said')],
                        [sg.Input(key='import_dummy_standard_results', enable_events=True, visible=False, size=(0, 0)),
                         sg.FileBrowse('Import standard results', file_types=[("Text Files", "*.txt")],
                                       target='import_dummy_standard_results',
                                       key='import_standard_results_button', size=button_size, pad=button_pad),
-                        question_mark('Help')],
+                        question_mark_button('import_standard_results_help_button', padding=button_pad)],
                        [explanation('whatever needs ot be said')],
                        [sg.Input(key='import_dummy_behaviorspace_results', enable_events=True, visible=False,
                                  size=(0, 0)),
                         sg.FileBrowse('Import BehaviorSpace results', file_types=[("Text Files", "*.txt")],
                                       target='import_dummy_behaviorspace_results',
                                       key='import_behaviorspace_results_button', size=button_size, pad=button_pad),
-                        question_mark('Help')],
+                        question_mark_button('import_behaviorspace_results_help_button', padding=button_pad)],
                        [explanation('whatever needs ot be said')],
                        [sg.Button('Back', key='import_back_button', pad=button_pad)]
                        ]
@@ -43,6 +45,15 @@ class ImportScreen:
             window['main_panel'].update(visible=True)
             window['import_panel'].update(visible=False)
 
+        # Help events
+        if event == 'import_experiment_results_help_button':
+            show_help_window(help_text['import_experiment'], location=window.CurrentLocation())
+        if event == 'import_standard_results_help_button':
+            show_help_window(help_text['import_standard'], location=window.CurrentLocation())
+        if event == 'import_behaviorspace_results_help_button':
+            show_help_window(help_text['import_behaviorspace'], location=window.CurrentLocation())
+
+
     def import_experiment_results(self, file_path, window):
         f = open(file_path, "r")
         experiment_string = f.read()
