@@ -1,21 +1,23 @@
 import PySimpleGUI as sg
+import plotly.graph_objects as go
 from NetLogoDOE.src.util.data_processing.merge_standard_data import merge_data
 import plotly.figure_factory as ff
-from NetLogoDOE.src.gui.custom_components import title, question_mark, metric3_radio_buttons
+from NetLogoDOE.src.gui.custom_components import title, metric3_radio_buttons, question_mark_button
+from NetLogoDOE.src.gui.custom_windows import show_help_window
+from NetLogoDOE.src.gui.help_dictionary import help_text
 
 
 class DistributionplotScreen:
 
     def __init__(self):
-        question_mark_padding = ((0, 0), (0, 0))
         self.layout = [[title('Distribution plot')],
                        [sg.Text('Graph Title:'), sg.Input('', key='distplot_title_input')],
-                       [sg.Text('Reporters to plot:'), question_mark('Help', padding=question_mark_padding)],
+                       [question_mark_button('distplot_reporter_help_button'), sg.Text('Reporters to plot:')],
                        [sg.Multiline('', key='distplot_reporter_input')],
                        [sg.Text('Only input a single reporter on each line')],
-                       [sg.Text('Metric:'), question_mark('Help', padding=question_mark_padding)],
+                       [question_mark_button('distplot_3metric_help_button'), sg.Text('Metric:')],
                        metric3_radio_buttons('distplot'),
-                       [sg.Text('Distribution indicators:'), question_mark('Help', padding=question_mark_padding)],
+                       [question_mark_button('distplot_indicators_help_button'), sg.Text('Distribution indicators:')],
                        [sg.Checkbox('Show curve', key='distplot_curve_checkbox', default=True),
                        sg.Checkbox('Show histogram', key='distplot_histogram_checkbox', default=True),
                        sg.Checkbox('Show rug', key='distplot_rug_checkbox', default=True)],
@@ -36,6 +38,14 @@ class DistributionplotScreen:
             window['distplot_panel'].update(visible=False)
             window['standard_result_panel'].update(visible=True)
 
+        # Help events
+        if event == 'distplot_reporter_help_button':
+            show_help_window(help_text['standard_plot_reporters'], location=window.CurrentLocation())
+        if event == 'distplot_3metric_help_button':
+            show_help_window(help_text['3_metric'], location=window.CurrentLocation())
+        if event == 'distplot_indicators_help_button':
+            show_help_window(help_text['distributionplot_indicators'], location=window.CurrentLocation())
+
     def generate_histogram(self, values, window):
         reporters = self.format_reporters(values)
         metric = self.get_selected_radio_button(values)
