@@ -4,19 +4,20 @@ import plotly.express as px
 from plotly.colors import hex_to_rgb
 import numpy as np
 from NetLogoDOE.src.util.data_processing.merge_standard_data import merge_data
-from NetLogoDOE.src.gui.custom_components import title, question_mark, metric3_radio_buttons
+from NetLogoDOE.src.gui.custom_components import title, question_mark_button, metric3_radio_buttons
+from NetLogoDOE.src.gui.custom_windows import show_help_window
+from NetLogoDOE.src.gui.help_dictionary import help_text
 
 
 class TimeSeriesplotScreen:
 
     def __init__(self):
-        question_mark_padding = ((0, 0), (0, 0))
         self.layout = [[title('Timeseries plot')],
                        [sg.Text('Graph Title'), sg.Input(key='timeseries_title_input')],
-                       [sg.Text('Reporters to plot:'), question_mark('Help', padding=question_mark_padding)],
+                       [question_mark_button('timeseries_reporter_help_button'), sg.Text('Reporters to plot:')],
                        [sg.Multiline('', key='timeseries_reporter_input')],
                        [sg.Text('Only input a single reporter on each line')],
-                       [sg.Text('Metric:'), question_mark('Help', padding=question_mark_padding)],
+                       [question_mark_button('timeseries_3metric_help_button'), sg.Text('Metric:')],
                        metric3_radio_buttons('timeseries'),
                        [self.collapse([
                            [sg.Text('Type of variance indication:')],
@@ -43,6 +44,12 @@ class TimeSeriesplotScreen:
             window['timeseries_panel'].update(visible=False)
             window['standard_result_panel'].update(visible=True)
 
+        # Help events
+        if event == 'timeseries_reporter_help_button':
+            show_help_window(help_text['standard_plot_reporters'], location=window.CurrentLocation())
+        if event == 'timeseries_3metric_help_button':
+            show_help_window(help_text['3_metric'], location=window.CurrentLocation())
+
     def collapse(self, layout, key):
         return sg.pin(sg.Column(layout, key=key, visible=False))
 
